@@ -37,8 +37,10 @@ test_that("escape solidus", {
 })
 
 test_that("BOM is being ignored", {
-  expect_warning(fromJSON('\uFEFF[123]'), "mark")
-  expect_warning(fromJSON(rawConnection(charToRaw('\uFEFF[123]'))), "mark")
-  expect_equal(fromJSON('\uFEFF[123]'), 123)
-  expect_equal(fromJSON(rawConnection(charToRaw('\uFEFF[123]'))), 123)
+  expect_warning(x <- fromJSON('\uFEFF[123]'), "mark")
+  expect_equal(x, 123)
+  con <- rawConnection(charToRaw('\uFEFF[123]'))
+  expect_warning(fromJSON(con), "mark")
+  close(con)
+  expect_equal(x, 123)
 })
